@@ -35,11 +35,14 @@ import (
 	"github.com/openshift/hive/pkg/apis"
 	hivev1 "github.com/openshift/hive/pkg/apis/hive/v1"
 	hivev1aws "github.com/openshift/hive/pkg/apis/hive/v1/aws"
+	hivev1azure "github.com/openshift/hive/pkg/apis/hive/v1/azure"
 	"github.com/openshift/hive/pkg/apis/hive/v1/baremetal"
+	hiveintv1alpha1 "github.com/openshift/hive/pkg/apis/hiveinternal/v1alpha1"
 	"github.com/openshift/hive/pkg/constants"
 	controllerutils "github.com/openshift/hive/pkg/controller/utils"
 	"github.com/openshift/hive/pkg/remoteclient"
 	remoteclientmock "github.com/openshift/hive/pkg/remoteclient/mock"
+	testclusterdeprovision "github.com/openshift/hive/pkg/test/clusterdeprovision"
 )
 
 const (
@@ -67,6 +70,7 @@ contexts:
 current-context: admin
 `
 	adminPasswordSecret = "foo-lqmsh-admin-password"
+	adminPassword       = "foo"
 
 	remoteClusterRouteObjectName      = "console"
 	remoteClusterRouteObjectNamespace = "openshift-console"
@@ -124,6 +128,7 @@ func TestClusterDeploymentReconcile(t *testing.T) {
 		validate                func(client.Client, *testing.T)
 		reconcilerSetup         func(*ReconcileClusterDeployment)
 	}{
+
 		{
 			name: "Add finalizer",
 			existing: []runtime.Object{
@@ -317,6 +322,7 @@ func TestClusterDeploymentReconcile(t *testing.T) {
 				testInstallLogPVC(),
 				testMetadataConfigMap(),
 				testSecret(corev1.SecretTypeOpaque, adminKubeconfigSecret, "kubeconfig", adminKubeconfig),
+				testSecret(corev1.SecretTypeOpaque, adminPasswordSecret, "password", adminPassword),
 				testSecret(corev1.SecretTypeDockerConfigJson, pullSecretSecret, corev1.DockerConfigJsonKey, "{}"),
 				testSecret(corev1.SecretTypeDockerConfigJson, constants.GetMergedPullSecretName(testClusterDeployment()), corev1.DockerConfigJsonKey, "{}"),
 			},
@@ -339,6 +345,7 @@ func TestClusterDeploymentReconcile(t *testing.T) {
 				testInstallLogPVC(),
 				testMetadataConfigMap(),
 				testSecret(corev1.SecretTypeOpaque, adminKubeconfigSecret, "kubeconfig", adminKubeconfig),
+				testSecret(corev1.SecretTypeOpaque, adminPasswordSecret, "password", adminPassword),
 				testSecret(corev1.SecretTypeDockerConfigJson, pullSecretSecret, corev1.DockerConfigJsonKey, "{}"),
 				testSecret(corev1.SecretTypeDockerConfigJson, constants.GetMergedPullSecretName(testClusterDeployment()), corev1.DockerConfigJsonKey, "{}"),
 			},
@@ -359,6 +366,7 @@ func TestClusterDeploymentReconcile(t *testing.T) {
 				testInstallLogPVC(),
 				testMetadataConfigMap(),
 				testSecret(corev1.SecretTypeOpaque, adminKubeconfigSecret, "kubeconfig", adminKubeconfig),
+				testSecret(corev1.SecretTypeOpaque, adminPasswordSecret, "password", adminPassword),
 				testSecret(corev1.SecretTypeDockerConfigJson, pullSecretSecret, corev1.DockerConfigJsonKey, "{}"),
 				testSecret(corev1.SecretTypeDockerConfigJson, constants.GetMergedPullSecretName(testClusterDeployment()), corev1.DockerConfigJsonKey, "{}"),
 			},
@@ -387,6 +395,7 @@ func TestClusterDeploymentReconcile(t *testing.T) {
 				testInstalledClusterDeployment(time.Date(2019, 9, 6, 11, 58, 32, 45, time.UTC)),
 				testMetadataConfigMap(),
 				testSecret(corev1.SecretTypeOpaque, adminKubeconfigSecret, "kubeconfig", adminKubeconfig),
+				testSecret(corev1.SecretTypeOpaque, adminPasswordSecret, "password", adminPassword),
 				testSecret(corev1.SecretTypeDockerConfigJson, pullSecretSecret, corev1.DockerConfigJsonKey, "{}"),
 				testSecret(corev1.SecretTypeDockerConfigJson, constants.GetMergedPullSecretName(testClusterDeployment()), corev1.DockerConfigJsonKey, "{}"),
 			},
@@ -682,6 +691,42 @@ func TestClusterDeploymentReconcile(t *testing.T) {
 				assertConditionStatus(t, cd, hivev1.DNSNotReadyCondition, corev1.ConditionTrue)
 			},
 		},
+		{
+			name: "Set condition when DNSZone cannot be created due to credentials missing permissions",
+			existing: []runtime.Object{
+				func() *hivev1.ClusterDeployment {
+					cd := testClusterDeployment()
+					cd.Spec.ManageDNS = true
+					return cd
+				}(),
+				testSecret(corev1.SecretTypeDockerConfigJson, pullSecretSecret, corev1.DockerConfigJsonKey, "{}"),
+				testSecret(corev1.SecretTypeDockerConfigJson, constants.GetMergedPullSecretName(testClusterDeployment()), corev1.DockerConfigJsonKey, "{}"),
+				testDNSZoneWithInvalidCredentialsCondition(),
+			},
+			validate: func(c client.Client, t *testing.T) {
+				cd := getCD(c)
+				assertConditionStatus(t, cd, hivev1.DNSNotReadyCondition, corev1.ConditionTrue)
+				assertConditionReason(t, cd, hivev1.DNSNotReadyCondition, "InsufficientCredentials")
+			},
+		},
+		{
+			name: "Set condition when DNSZone cannot be created due to authentication failure",
+			existing: []runtime.Object{
+				func() *hivev1.ClusterDeployment {
+					cd := testClusterDeployment()
+					cd.Spec.ManageDNS = true
+					return cd
+				}(),
+				testSecret(corev1.SecretTypeDockerConfigJson, pullSecretSecret, corev1.DockerConfigJsonKey, "{}"),
+				testSecret(corev1.SecretTypeDockerConfigJson, constants.GetMergedPullSecretName(testClusterDeployment()), corev1.DockerConfigJsonKey, "{}"),
+				testDNSZoneWithAuthenticationFailureCondition(),
+			},
+			validate: func(c client.Client, t *testing.T) {
+				cd := getCD(c)
+				assertConditionStatus(t, cd, hivev1.DNSNotReadyCondition, corev1.ConditionTrue)
+				assertConditionReason(t, cd, hivev1.DNSNotReadyCondition, "AuthenticationFailure")
+			},
+		},
 		{
 			name: "Clear condition when DNSZone is available",
 			existing: []runtime.Object{
@@ -907,7 +952,7 @@ func TestClusterDeploymentReconcile(t *testing.T) {
 				testSecret(corev1.SecretTypeDockerConfigJson, pullSecretSecret, corev1.DockerConfigJsonKey, "{}"),
 				testSecret(corev1.SecretTypeDockerConfigJson, constants.GetMergedPullSecretName(testClusterDeployment()), corev1.DockerConfigJsonKey, "{}"),
 			},
-			expectedRequeueAfter: 8*time.Hour + 60*time.Second,
+			expectedRequeueAfter: 8 * time.Hour,
 		},
 		{
 			name: "Wait after failed provision",
@@ -1021,10 +1066,25 @@ func TestClusterDeploymentReconcile(t *testing.T) {
 			},
 		},
 		{
-			name: "setSyncSetFailedCondition should be present",
+			name: "SyncSetFailedCondition should be present",
 			existing: []runtime.Object{
 				testInstalledClusterDeployment(time.Now()),
-				createSyncSetInstanceObj(hivev1.ApplyFailureSyncCondition),
+				testSecret(corev1.SecretTypeOpaque, adminKubeconfigSecret, "kubeconfig", adminKubeconfig),
+				testSecret(corev1.SecretTypeOpaque, adminPasswordSecret, "password", adminPassword),
+				&hiveintv1alpha1.ClusterSync{
+					ObjectMeta: metav1.ObjectMeta{
+						Namespace: testNamespace,
+						Name:      testName,
+					},
+					Status: hiveintv1alpha1.ClusterSyncStatus{
+						Conditions: []hiveintv1alpha1.ClusterSyncCondition{{
+							Type:    hiveintv1alpha1.ClusterSyncFailed,
+							Status:  corev1.ConditionTrue,
+							Reason:  "FailureReason",
+							Message: "Failure message",
+						}},
+					},
+				},
 			},
 			validate: func(c client.Client, t *testing.T) {
 				cd := getCD(c)
@@ -1037,9 +1097,8 @@ func TestClusterDeploymentReconcile(t *testing.T) {
 			},
 		},
 		{
-			name: "setSyncSetFailedCondition value should be corev1.ConditionFalse",
+			name: "SyncSetFailedCondition value should be corev1.ConditionFalse",
 			existing: []runtime.Object{
-
 				func() runtime.Object {
 					cd := testInstalledClusterDeployment(time.Now())
 					cd.Status.Conditions = append(
@@ -1051,7 +1110,22 @@ func TestClusterDeploymentReconcile(t *testing.T) {
 					)
 					return cd
 				}(),
-				createSyncSetInstanceObj(hivev1.ApplySuccessSyncCondition),
+				testSecret(corev1.SecretTypeOpaque, adminKubeconfigSecret, "kubeconfig", adminKubeconfig),
+				testSecret(corev1.SecretTypeOpaque, adminPasswordSecret, "password", adminPassword),
+				&hiveintv1alpha1.ClusterSync{
+					ObjectMeta: metav1.ObjectMeta{
+						Namespace: testNamespace,
+						Name:      testName,
+					},
+					Status: hiveintv1alpha1.ClusterSyncStatus{
+						Conditions: []hiveintv1alpha1.ClusterSyncCondition{{
+							Type:    hiveintv1alpha1.ClusterSyncFailed,
+							Status:  corev1.ConditionFalse,
+							Reason:  "SuccessReason",
+							Message: "Success message",
+						}},
+					},
+				},
 			},
 			validate: func(c client.Client, t *testing.T) {
 				cd := getCD(c)
@@ -1154,9 +1228,260 @@ func TestClusterDeploymentReconcile(t *testing.T) {
 			validate: func(c client.Client, t *testing.T) {
 				cd := getCD(c)
 				require.Equal(t, 1, len(cd.Status.Conditions))
+				require.Equal(t, corev1.ConditionTrue, cd.Status.Conditions[0].Status)
 				require.Equal(t, clusterImageSetNotFoundReason, cd.Status.Conditions[0].Reason)
 			},
 		},
+		{
+			name: "clear ClusterImageSet missing condition",
+			existing: []runtime.Object{
+				func() *hivev1.ClusterDeployment {
+					cd := testClusterDeployment()
+					cd.Spec.Provisioning.ImageSetRef = &hivev1.ClusterImageSetReference{Name: testClusterImageSetName}
+					cd.Status.Conditions = []hivev1.ClusterDeploymentCondition{{
+						Type:    hivev1.ClusterImageSetNotFoundCondition,
+						Status:  corev1.ConditionTrue,
+						Reason:  "test-reason",
+						Message: "test-message",
+					}}
+					return cd
+				}(),
+				testClusterImageSet(),
+				testSecret(corev1.SecretTypeDockerConfigJson, pullSecretSecret, corev1.DockerConfigJsonKey, "{}"),
+				testSecret(corev1.SecretTypeDockerConfigJson, constants.GetMergedPullSecretName(testClusterDeployment()), corev1.DockerConfigJsonKey, "{}"),
+			},
+			expectPendingCreation: true,
+			validate: func(c client.Client, t *testing.T) {
+				cd := getCD(c)
+				require.Equal(t, 1, len(cd.Status.Conditions))
+				require.Equal(t, corev1.ConditionFalse, cd.Status.Conditions[0].Status)
+				require.Equal(t, clusterImageSetFoundReason, cd.Status.Conditions[0].Reason)
+			},
+		},
+		{
+			name: "Add ownership to admin secrets",
+			existing: []runtime.Object{
+				func() *hivev1.ClusterDeployment {
+					cd := testClusterDeployment()
+					cd.Spec.Installed = true
+					cd.Spec.ClusterMetadata = &hivev1.ClusterMetadata{
+						InfraID:                  "fakeinfra",
+						AdminKubeconfigSecretRef: corev1.LocalObjectReference{Name: adminKubeconfigSecret},
+						AdminPasswordSecretRef:   corev1.LocalObjectReference{Name: adminPasswordSecret},
+					}
+					cd.Status.WebConsoleURL = "https://example.com"
+					cd.Status.APIURL = "https://example.com"
+					return cd
+				}(),
+				testSecret(corev1.SecretTypeOpaque, adminKubeconfigSecret, "kubeconfig", adminKubeconfig),
+				testSecret(corev1.SecretTypeOpaque, adminPasswordSecret, "password", adminPassword),
+				testSecret(corev1.SecretTypeDockerConfigJson, pullSecretSecret, corev1.DockerConfigJsonKey, "{}"),
+				testSecret(corev1.SecretTypeDockerConfigJson, constants.GetMergedPullSecretName(
+					testClusterDeployment()), corev1.DockerConfigJsonKey, "{}"),
+				testMetadataConfigMap(),
+			},
+			validate: func(c client.Client, t *testing.T) {
+				secretNames := []string{adminKubeconfigSecret, adminPasswordSecret}
+				for _, secretName := range secretNames {
+					secret := &corev1.Secret{}
+					err := c.Get(context.TODO(), client.ObjectKey{Name: secretName, Namespace: testNamespace},
+						secret)
+					require.NoErrorf(t, err, "not found secret %s", secretName)
+					require.NotNilf(t, secret, "expected secret %s", secretName)
+					assert.Equalf(t, testClusterDeployment().Name, secret.Labels[constants.ClusterDeploymentNameLabel],
+						"incorrect cluster deployment name label for %s", secretName)
+					refs := secret.GetOwnerReferences()
+					cdAsOwnerRef := false
+					for _, ref := range refs {
+						if ref.Name == testName {
+							cdAsOwnerRef = true
+						}
+					}
+					assert.Truef(t, cdAsOwnerRef, "cluster deployment not owner of %s", secretName)
+				}
+			},
+		},
+		{
+			name: "delete finalizer when deprovision complete and dnszone gone",
+			existing: []runtime.Object{
+				func() *hivev1.ClusterDeployment {
+					cd := testClusterDeployment()
+					cd.Spec.ManageDNS = true
+					cd.Spec.Installed = true
+					now := metav1.Now()
+					cd.DeletionTimestamp = &now
+					return cd
+				}(),
+				testclusterdeprovision.Build(
+					testclusterdeprovision.WithNamespace(testNamespace),
+					testclusterdeprovision.WithName(testName),
+					testclusterdeprovision.Completed(),
+				),
+			},
+			validate: func(c client.Client, t *testing.T) {
+				cd := getCD(c)
+				require.NotNil(t, cd, "could not get ClusterDeployment")
+				assert.NotContains(t, cd.Finalizers, hivev1.FinalizerDeprovision, "expected finalizer to be removed from ClusterDeployment")
+			},
+		},
+		{
+			name: "wait for deprovision to complete",
+			existing: []runtime.Object{
+				func() *hivev1.ClusterDeployment {
+					cd := testClusterDeployment()
+					cd.Spec.ManageDNS = true
+					cd.Spec.Installed = true
+					now := metav1.Now()
+					cd.DeletionTimestamp = &now
+					return cd
+				}(),
+				testclusterdeprovision.Build(
+					testclusterdeprovision.WithNamespace(testNamespace),
+					testclusterdeprovision.WithName(testName),
+				),
+			},
+			validate: func(c client.Client, t *testing.T) {
+				cd := getCD(c)
+				require.NotNil(t, cd, "could not get ClusterDeployment")
+				assert.Contains(t, cd.Finalizers, hivev1.FinalizerDeprovision, "expected finalizer to be removed from ClusterDeployment")
+			},
+		},
+		{
+			name: "wait for dnszone to be gone",
+			existing: []runtime.Object{
+				func() *hivev1.ClusterDeployment {
+					cd := testClusterDeployment()
+					cd.Spec.ManageDNS = true
+					cd.Spec.Installed = true
+					now := metav1.Now()
+					cd.DeletionTimestamp = &now
+					return cd
+				}(),
+				testclusterdeprovision.Build(
+					testclusterdeprovision.WithNamespace(testNamespace),
+					testclusterdeprovision.WithName(testName),
+					testclusterdeprovision.Completed(),
+				),
+				func() *hivev1.DNSZone {
+					dnsZone := testDNSZone()
+					now := metav1.Now()
+					dnsZone.DeletionTimestamp = &now
+					return dnsZone
+				}(),
+			},
+			validate: func(c client.Client, t *testing.T) {
+				cd := getCD(c)
+				require.NotNil(t, cd, "could not get ClusterDeployment")
+				assert.Contains(t, cd.Finalizers, hivev1.FinalizerDeprovision, "expected finalizer to be removed from ClusterDeployment")
+			},
+			expectedRequeueAfter: defaultRequeueTime,
+		},
+		{
+			name: "do not wait for dnszone to be gone when not using managed dns",
+			existing: []runtime.Object{
+				func() *hivev1.ClusterDeployment {
+					cd := testClusterDeployment()
+					cd.Spec.Installed = true
+					now := metav1.Now()
+					cd.DeletionTimestamp = &now
+					return cd
+				}(),
+				testclusterdeprovision.Build(
+					testclusterdeprovision.WithNamespace(testNamespace),
+					testclusterdeprovision.WithName(testName),
+					testclusterdeprovision.Completed(),
+				),
+				func() *hivev1.DNSZone {
+					dnsZone := testDNSZone()
+					now := metav1.Now()
+					dnsZone.DeletionTimestamp = &now
+					return dnsZone
+				}(),
+			},
+			validate: func(c client.Client, t *testing.T) {
+				cd := getCD(c)
+				require.NotNil(t, cd, "could not get ClusterDeployment")
+				assert.NotContains(t, cd.Finalizers, hivev1.FinalizerDeprovision, "expected finalizer to be removed from ClusterDeployment")
+			},
+		},
+		{
+			name: "wait for dnszone to be gone when install failed early",
+			existing: []runtime.Object{
+				func() *hivev1.ClusterDeployment {
+					cd := testClusterDeployment()
+					cd.Spec.ManageDNS = true
+					now := metav1.Now()
+					cd.DeletionTimestamp = &now
+					cd.Spec.ClusterMetadata = nil
+					return cd
+				}(),
+				func() *hivev1.DNSZone {
+					dnsZone := testDNSZone()
+					now := metav1.Now()
+					dnsZone.DeletionTimestamp = &now
+					return dnsZone
+				}(),
+			},
+			validate: func(c client.Client, t *testing.T) {
+				cd := getCD(c)
+				require.NotNil(t, cd, "could not get ClusterDeployment")
+				assert.Contains(t, cd.Finalizers, hivev1.FinalizerDeprovision, "expected finalizer to be removed from ClusterDeployment")
+			},
+			expectedRequeueAfter: defaultRequeueTime,
+		},
+		{
+			name: "set InstallLaunchErrorCondition when install pod is stuck in pending phase",
+			existing: []runtime.Object{
+				testClusterDeploymentWithProvision(),
+				testProvisionWithStuckInstallPod(),
+				testSecret(corev1.SecretTypeDockerConfigJson, pullSecretSecret, corev1.DockerConfigJsonKey, "{}"),
+				testSecret(corev1.SecretTypeDockerConfigJson, constants.GetMergedPullSecretName(testClusterDeployment()), corev1.DockerConfigJsonKey, "{}"),
+			},
+			validate: func(c client.Client, t *testing.T) {
+				cd := getCD(c)
+				require.NotNil(t, cd, "could not get ClusterDeployment")
+				assertConditionStatus(t, cd, hivev1.InstallLaunchErrorCondition, corev1.ConditionTrue)
+				assertConditionReason(t, cd, hivev1.InstallLaunchErrorCondition, "PodInPendingPhase")
+			},
+		},
+		{
+			name: "set resourcegroupname for Azure deprovision",
+			existing: []runtime.Object{
+				func() *hivev1.ClusterDeployment {
+					cd := testClusterDeploymentWithProvision()
+					cd.Spec.Platform.AWS = nil
+					cd.Spec.Platform.Azure = &hivev1azure.Platform{
+						CredentialsSecretRef: corev1.LocalObjectReference{
+							Name: "azure-credentials",
+						},
+						Region:            "centralus",
+						ResourceGroupName: "manual-resourcegroup",
+					}
+					cd.Labels[hivev1.HiveClusterPlatformLabel] = "azure"
+					cd.Labels[hivev1.HiveClusterRegionLabel] = "centralus"
+
+					now := metav1.Now()
+					cd.DeletionTimestamp = &now
+
+					return cd
+				}(),
+				testSecret(corev1.SecretTypeDockerConfigJson, pullSecretSecret, corev1.DockerConfigJsonKey, "{}"),
+			},
+			validate: func(c client.Client, t *testing.T) {
+				cd := getCD(c)
+				require.NotNil(t, cd, "could not get ClusterDeployment")
+
+				deprovisionKey := types.NamespacedName{
+					Name:      cd.Name,
+					Namespace: cd.Namespace,
+				}
+				deprovision := &hivev1.ClusterDeprovision{}
+				err := c.Get(context.TODO(), deprovisionKey, deprovision)
+				require.NoError(t, err, "failed to get ClusterDeprovision")
+
+				assert.Equal(t, "manual-resourcegroup", deprovision.Spec.Platform.Azure.ResourceGroupName)
+			},
+		},
 	}
 
 	for _, test := range tests {
@@ -1592,6 +1917,19 @@ func testFailedProvisionTime(time time.Time) *hivev1.ClusterProvision {
 	return provision
 }
 
+func testProvisionWithStuckInstallPod() *hivev1.ClusterProvision {
+	provision := testProvision()
+	provision.Status.Conditions = []hivev1.ClusterProvisionCondition{
+		{
+			Type:    hivev1.InstallPodStuckCondition,
+			Status:  corev1.ConditionTrue,
+			Reason:  "PodInPendingPhase",
+			Message: "pod is in pending phase",
+		},
+	}
+	return provision
+}
+
 func testOldFailedProvision(time time.Time, attempt int) *hivev1.ClusterProvision {
 	provision := testProvision()
 	provision.Name = fmt.Sprintf("%s-%02d", provision.Name, attempt)
@@ -1685,6 +2023,34 @@ func testAvailableDNSZone() *hivev1.DNSZone {
 	return zone
 }
 
+func testDNSZoneWithInvalidCredentialsCondition() *hivev1.DNSZone {
+	zone := testDNSZone()
+	zone.Status.Conditions = []hivev1.DNSZoneCondition{
+		{
+			Type:   hivev1.InsufficientCredentialsCondition,
+			Status: corev1.ConditionTrue,
+			LastTransitionTime: metav1.Time{
+				Time: time.Now(),
+			},
+		},
+	}
+	return zone
+}
+
+func testDNSZoneWithAuthenticationFailureCondition() *hivev1.DNSZone {
+	zone := testDNSZone()
+	zone.Status.Conditions = []hivev1.DNSZoneCondition{
+		{
+			Type:   hivev1.AuthenticationFailureCondition,
+			Status: corev1.ConditionTrue,
+			LastTransitionTime: metav1.Time{
+				Time: time.Now(),
+			},
+		},
+	}
+	return zone
+}
+
 func assertConditionStatus(t *testing.T, cd *hivev1.ClusterDeployment, condType hivev1.ClusterDeploymentConditionType, status corev1.ConditionStatus) {
 	found := false
 	for _, cond := range cd.Status.Conditions {
@@ -1696,6 +2062,16 @@ func assertConditionStatus(t *testing.T, cd *hivev1.ClusterDeployment, condType
 	assert.True(t, found, "did not find expected condition type: %v", condType)
 }
 
+func assertConditionReason(t *testing.T, cd *hivev1.ClusterDeployment, condType hivev1.ClusterDeploymentConditionType, reason string) {
+	for _, cond := range cd.Status.Conditions {
+		if cond.Type == condType {
+			assert.Equal(t, reason, cond.Reason, "condition found with unexpected reason")
+			return
+		}
+	}
+	t.Errorf("did not find expected condition type: %v", condType)
+}
+
 func getJob(c client.Client, name string) *batchv1.Job {
 	job := &batchv1.Job{}
 	err := c.Get(context.TODO(), client.ObjectKey{Name: name, Namespace: testNamespace}, job)
@@ -1957,42 +2333,6 @@ func getProvisions(c client.Client) []*hivev1.ClusterProvision {
 	return provisions
 }
 
-func createSyncSetInstanceObj(syncCondType hivev1.SyncConditionType) *hivev1.SyncSetInstance {
-	ssi := &hivev1.SyncSetInstance{
-		ObjectMeta: metav1.ObjectMeta{
-			Name:      testSyncsetInstanceName,
-			Namespace: testNamespace,
-		},
-	}
-	ssi.Spec.ClusterDeploymentRef.Name = testName
-	ssi.Status = createSyncSetInstanceStatus(syncCondType)
-	return ssi
-}
-
-func createSyncSetInstanceStatus(syncCondType hivev1.SyncConditionType) hivev1.SyncSetInstanceStatus {
-	conditionTime := metav1.NewTime(time.Now())
-	var ssiStatus corev1.ConditionStatus
-	var condType hivev1.SyncConditionType
-	if syncCondType == hivev1.ApplyFailureSyncCondition {
-		ssiStatus = corev1.ConditionTrue
-		condType = syncCondType
-	} else {
-		ssiStatus = corev1.ConditionFalse
-		condType = syncCondType
-	}
-	status := hivev1.SyncSetInstanceStatus{
-		Conditions: []hivev1.SyncCondition{
-			{
-				Type:               condType,
-				Status:             ssiStatus,
-				LastTransitionTime: conditionTime,
-				LastProbeTime:      conditionTime,
-			},
-		},
-	}
-	return status
-}
-
 func testCompletedImageSetJob() *batchv1.Job {
 	return &batchv1.Job{
 		ObjectMeta: metav1.ObjectMeta{
