@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package v2_5_experimental
+package v2_4_experimental
 
 import (
 	"net/url"
@@ -21,8 +21,8 @@ import (
 	"github.com/stretchr/testify/assert"
 
 	"github.com/coreos/ignition/config/util"
-	from "github.com/coreos/ignition/config/v2_4/types"
-	"github.com/coreos/ignition/config/v2_5_experimental/types"
+	from "github.com/coreos/ignition/config/v2_3/types"
+	"github.com/coreos/ignition/config/v2_4_experimental/types"
 )
 
 func TestTranslate(t *testing.T) {
@@ -235,121 +235,6 @@ func TestTranslate(t *testing.T) {
 				},
 			}},
 		},
-		{
-			in: in{config: from.Config{
-				Ignition: from.Ignition{
-					Proxy: from.Proxy{
-						HTTPProxy:  "http://127.0.0.1:8080",
-						HTTPSProxy: "",
-						NoProxy:    nil,
-					},
-				},
-			}},
-			out: out{config: types.Config{
-				Ignition: types.Ignition{
-					Version: types.MaxVersion.String(),
-					Proxy: types.Proxy{
-						HTTPProxy:  "http://127.0.0.1:8080",
-						HTTPSProxy: "",
-						NoProxy:    nil,
-					},
-				},
-			}},
-		},
-		{
-			in: in{config: from.Config{
-				Ignition: from.Ignition{
-					Proxy: from.Proxy{
-						HTTPProxy:  "http://127.0.0.1:8080",
-						HTTPSProxy: "http://127.0.0.1:8080",
-						NoProxy:    nil,
-					},
-				},
-			}},
-			out: out{config: types.Config{
-				Ignition: types.Ignition{
-					Version: types.MaxVersion.String(),
-					Proxy: types.Proxy{
-						HTTPProxy:  "http://127.0.0.1:8080",
-						HTTPSProxy: "http://127.0.0.1:8080",
-						NoProxy:    nil,
-					},
-				},
-			}},
-		},
-		{
-			in: in{config: from.Config{
-				Ignition: from.Ignition{
-					Proxy: from.Proxy{
-						HTTPProxy:  "http://proxy.tld:1234",
-						HTTPSProxy: "https://proxy.tld:1235",
-						NoProxy:    nil,
-					},
-				},
-			}},
-			out: out{config: types.Config{
-				Ignition: types.Ignition{
-					Version: types.MaxVersion.String(),
-					Proxy: types.Proxy{
-						HTTPProxy:  "http://proxy.tld:1234",
-						HTTPSProxy: "https://proxy.tld:1235",
-						NoProxy:    nil,
-					},
-				},
-			}},
-		},
-		{
-			in: in{config: from.Config{
-				Ignition: from.Ignition{
-					Proxy: from.Proxy{
-						HTTPProxy:  "http://proxy.tld:1234",
-						HTTPSProxy: "https://proxy.tld:1235",
-						NoProxy: []from.NoProxyItem{
-							from.NoProxyItem("noproxy.tld"),
-						},
-					},
-				},
-			}},
-			out: out{config: types.Config{
-				Ignition: types.Ignition{
-					Version: types.MaxVersion.String(),
-					Proxy: types.Proxy{
-						HTTPProxy:  "http://proxy.tld:1234",
-						HTTPSProxy: "https://proxy.tld:1235",
-						NoProxy: []types.NoProxyItem{
-							types.NoProxyItem("noproxy.tld"),
-						},
-					},
-				},
-			}},
-		},
-		{
-			in: in{config: from.Config{
-				Ignition: from.Ignition{
-					Proxy: from.Proxy{
-						HTTPProxy:  "http://proxy.tld:1234",
-						HTTPSProxy: "https://proxy.tld:1235",
-						NoProxy: []from.NoProxyItem{
-							from.NoProxyItem("noproxy.tld"),
-							from.NoProxyItem("example.com"),
-						},
-					},
-				},
-			}},
-			out: out{config: types.Config{
-				Ignition: types.Ignition{
-					Version: types.MaxVersion.String(),
-					Proxy: types.Proxy{
-						HTTPProxy:  "http://proxy.tld:1234",
-						HTTPSProxy: "https://proxy.tld:1235",
-						NoProxy: []types.NoProxyItem{
-							types.NoProxyItem("noproxy.tld"),
-							types.NoProxyItem("example.com"),
-						},
-					},
-				},
-			}},
-		},
 		{
 			in: in{config: from.Config{
 				Ignition: from.Ignition{Version: from.MaxVersion.String()},
